@@ -24,7 +24,7 @@ import gcompris.bonus
 import gtk
 import gtk.gdk
 import gobject
-from gettext import gettext as _
+from gcompris import gcompris_gettext as _
 
 # Database
 from pysqlite2 import dbapi2 as sqlite
